@@ -159,6 +159,7 @@ def Trajectory(data,bodyPartTraj,bodyPartBox, **kwargs):
         cax = divider.append_axes('right',size='5%', pad=0.05)
         cb = fig.colorbar(plot,cax=cax)
         cb.ax.tick_params(labelsize=fontsize)
+        cb.set_label(label='Time (s)', fontsize=fontsize)
 
         if invertY == True:
             ax.invert_yaxis()
@@ -403,7 +404,7 @@ def MotionMetrics (data,bodyPart,filter=0,fps=30,max_real=60,min_real=0):
 
     return df
 
-def FieldDetermination(Fields,plot=False,**kwargs):
+def FieldDetermination(Fields=1,plot=False,**kwargs):
     """
     Creates a data frame with the desired dimensions to extract information about
     an area. Therefore, you must determine the area in which you want to extract 
@@ -469,6 +470,7 @@ def FieldDetermination(Fields,plot=False,**kwargs):
     import matplotlib.patches as patches
       
     ax = kwargs.get('ax')
+    ret = kwargs.get('ret')
     posit = kwargs.get('posit')
     data = kwargs.get('data')
     bodyPartBox = kwargs.get('bodyPartBox')
@@ -478,6 +480,8 @@ def FieldDetermination(Fields,plot=False,**kwargs):
     obj_color = kwargs.get('obj_color')
     if type(obj_color) == type(None):
       obj_color = 'r'
+    if type(ret) == type(None):
+      ret = True
 
     null = 0
     fields = pd.DataFrame(columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y' , 'height', 'width'])
@@ -523,7 +527,6 @@ def FieldDetermination(Fields,plot=False,**kwargs):
                                  columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y','height', 'width'])
             if posit[v][0] == 1:
                 rect.append(patches.Rectangle((float(posit[v][4]),float(posit[v][5])), float(posit[v][6]), float(posit[v][7]), linewidth=1, edgecolor=obj_color, facecolor='none'))
-                print(posit[v][0])
             if posit[v][0] == 0:
                 circle.append(plt.Circle((float(posit[v][1]),float(posit[v][2])), float(posit[v][3]), color=obj_color,fill = False))
             fields = fields.append(df2, ignore_index=True)
@@ -540,7 +543,8 @@ def FieldDetermination(Fields,plot=False,**kwargs):
         for i in range(len(rect)):
             ax.add_patch(rect[i])
 
-    return fields
+    if type(ret) == True:
+            return fields
 
 def Interaction(data,bodyPart,fields,fps=30):
     """
